##  What is Application Rationalization?
Application rationalization is the act of streamlining an existing application portfolio to improve efficiency, reduce complexity, make room for innovation, and lower the total cost of ownership (TCO) through a specific set of processes.
